//provides a proxy which connects to a cam daemon socket on behalf of pmt files.

#ifndef __PMT_PROXY__
#define __PMT_PROXY__

#include "btkcam.h"

#include <signal.h>
#include <unistd.h>
#include <fcntl.h>
#include <pthread.h>
#include <stdlib.h>
#include <time.h>
#include <sys/types.h>
#include <sys/socket.h>
#include <sys/un.h>
#include <sys/poll.h>

#include <netinet/in.h>
#include <netdb.h>
#include <errno.h>

//to support up to 2 pmt files
#define MAX_CONNECTION_COUNT 2

typedef enum
{
	NO_TRANSLATION,
	DGSTATION_DEVICES
} pmt_translation_t;

struct pmt_proxy_connection
{
	time_t timestamp;
	int camd_socket_fd;
};

class pmt_proxy
{
	//all static members (static class)
	public:
	static void start( pmt_translation_t device, char *camd_socket );
	static void stop( void );
	static bool ready;
	
	private:
	static int dir_fd;
	static pmt_translation_t translation;
	static char camd_socket_path[32];
	static char pmt_file_path[32];
	static char pmt_filename_pattern[32];
	static struct pmt_proxy_connection connections[MAX_CONNECTION_COUNT];
	static unsigned char *translate(unsigned int pmt_index, unsigned char *dest, unsigned int *dest_length, unsigned char *src, unsigned int src_length);
	static unsigned char *load(int fd, size_t size);
	static int connect_unix_socket(char *path);
	static void event_handler(int signal);
	
	//this class cannot be instantiated
	private:
	pmt_proxy();
	~pmt_proxy();
};

#endif
